@@ -5,6 +5,9 @@ import (
 	"encoding/json"
 	"fmt"
 	"net"
+	"net/url"
+	"os"
+	"path/filepath"
 	"strconv"
 
 	"github.com/apparentlymart/go-cidr/cidr"
@@ -23,6 +26,7 @@ type config struct {
 	MasterMemory    string   `json:"libvirt_master_memory,omitempty"`
 	MasterVcpu      string   `json:"libvirt_master_vcpu,omitempty"`
 	BootstrapMemory int      `json:"libvirt_bootstrap_memory,omitempty"`
+	MasterDiskSize  string   `json:"libvirt_master_size,omitempty"`
 }
 
 // TFVars generates libvirt-specific Terraform variables.
@@ -37,9 +41,21 @@ func TFVars(masterConfig *v1beta1.LibvirtMachineProviderConfig, osImage string,
 		return nil, err
 	}
 
-	osImage, err = cache.DownloadImageFile(osImage)
+	url, err := url.Parse(osImage)
 	if err != nil {
-		return nil, errors.Wrap(err, "failed to use cached libvirt image")
+		return nil, errors.Wrap(err, "failed to parse image url")
+	}
+
+	if url.Scheme == "file" {
+		osImage = filepath.FromSlash(url.Path)
+		if _, err = os.Stat(osImage); err != nil {
+			return nil, errors.Wrap(err, "failed to access file or directory")
+		}
+	} else {
+		osImage, err = cache.DownloadImageFile(osImage)
+		if err != nil {
+			return nil, errors.Wrap(err, "failed to use cached libvirt image")
+		}
 	}
 
 	cfg := &config{
@@ -52,8 +68,8 @@ func TFVars(masterConfig *v1beta1.LibvirtMachineProviderConfig, osImage string,
 		MasterVcpu:   strconv.Itoa(masterConfig.DomainVcpu),
 	}
 
-	if architecture == types.ArchitecturePPC64LE {
-		cfg.BootstrapMemory = 5120
+	if masterConfig.Volume.VolumeSize != nil {
+		cfg.MasterDiskSize = masterConfig.Volume.VolumeSize.String()
 	}
 
 	return json.MarshalIndent(cfg, "", "  ")
